@@ -123,6 +123,8 @@ class CreateDevice:
             self.onepushfocus_url = '%s/ISAPI/PTZCtrl/channels/1/onepushfoucs/start' % self._base
             self.absoluteStatus_url = '%s/ISAPI/PTZCtrl/channels/1/status' % self._base
             self.imageFocus_url = '%s/ISAPI/Image/channels/1/focusConfiguration' % self._base
+            self.ptz_capabilities_url = '%s/ISAPI/PTZCtrl/capabilities' % self._base
+            self.ptz_autopan_url = '%s/ISAPI/PTZCtrl/channels/1/autopan' % self._base
 
         else:
             self.motion_url = '%s/MotionDetection/1' % self._base
@@ -137,6 +139,37 @@ class CreateDevice:
         self._xml_namespace = ""
 
     
+    def get_ptz_capabilities(self, element_to_query=None):
+        response = requests.get(
+            self.ptz_capabilities_url,
+            auth=self._auth_fn(self._username, self._password),
+            headers={'Content-Type': 'application/json'}
+            )
+        if response.status_code != 200:
+            return None
+
+        if element_to_query is None:
+            # print(response.text)
+            # 返回的是json格式的数据，返回的是一个字典
+            return response.text
+        try:
+            tree = tree_no_ns_from_string(response.text)
+
+            element_to_query = './/%s%s' % (
+                self._xml_namespace, element_to_query)
+            result = tree.findall(element_to_query)
+            if len(result) > 0:
+                
+
+                return result[0].text.strip()
+            
+
+        except AttributeError as attib_err:
+            
+            return None
+        return None
+    
+
     def get_absolutestatus(self, element_to_query=None):
         response = requests.get(
             self.ptz_absoluteEx_url,
@@ -147,6 +180,7 @@ class CreateDevice:
             return None
 
         if element_to_query is None:
+            # print(response.text)
             # 返回的是json格式的数据，返回的是一个字典
             return response.text
         try:
@@ -237,6 +271,38 @@ class CreateDevice:
             return None
         return None
     
+    def set_auopan(self,autoPan=0,element_to_query=None):
+        autoPan = 60 * autoPan
+        data_xml = '<?xml version="1.0" encoding="UTF-8"?><autoPanData><autoPan>' + str(autoPan) + '</autoPan></autoPanData> '
+        # 转换为UTF-8编码
+        data_xml = data_xml.encode('utf-8')
+        # print(data_xml)
+        response = requests.put(
+            self.ptz_autopan_url,
+            auth=self._auth_fn(self._username, self._password),
+            data=data_xml,
+            )
+        if response.status_code != 200:
+            print('http code:',response.status_code)
+            print('response:',response.text)
+            # log_response_errors(response)
+            return None
+
+        if element_to_query is None:
+            # print(response.text)
+            return response.text
+        try:
+            tree = tree_no_ns_from_string(response.text)
+
+            element_to_query = './/%s%s' % (
+                self._xml_namespace, element_to_query)
+            result = tree.findall(element_to_query)
+            if len(result) > 0:
+                return result[0].text.strip()
+        except AttributeError as attib_err:
+            return None
+        return None
+    
     def ir_test(self, element_to_query=None):
         response = requests.get(
             self.ir_url,
